==> apache-reef-0.11.0-incubating.tar.gz: apache-reef-0.11.0-incubating/lang/java/reef-examples/src/main/java/org/apache/reef/examples/scheduler/SchedulerREEFYarn.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.reef.examples.scheduler;

import org.apache.commons.cli.ParseException;
import org.apache.reef.runtime.yarn.client.YarnClientConfiguration;
import org.apache.reef.tang.Configuration;
import org.apache.reef.tang.exceptions.InjectionException;

import java.io.IOException;

import static org.apache.reef.examples.scheduler.SchedulerREEF.runTaskScheduler;

/**
 * REEF TaskScheduler on YARN runtime.
 */
public final class SchedulerREEFYarn {
  /**
   * Launch the scheduler with YARN client configuration
   * @param args
   * @throws InjectionException
   * @throws java.io.IOException
   */
  public final static void main(String[] args)
    throws InjectionException, IOException, ParseException {
    final Configuration runtimeConfiguration =
      YarnClientConfiguration.CONF.build();
    runTaskScheduler(runtimeConfiguration, args);
  }
}

==> apache-reef-0.12.0-incubating.tar.gz: apache-reef-0.12.0-incubating/lang/java/reef-examples/src/main/java/org/apache/reef/examples/scheduler/SchedulerREEFYarn.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.reef.examples.scheduler;

import org.apache.commons.cli.ParseException;
import org.apache.reef.runtime.yarn.client.YarnClientConfiguration;
import org.apache.reef.tang.Configuration;
import org.apache.reef.tang.exceptions.InjectionException;

import java.io.IOException;

import static org.apache.reef.examples.scheduler.SchedulerREEF.runTaskScheduler;

/**
 * REEF TaskScheduler on YARN runtime.
 */
public final class SchedulerREEFYarn {
  /**
   * Launch the scheduler with YARN client configuration.
   * @param args
   * @throws InjectionException
   * @throws java.io.IOException
   */
  public static void main(final String[] args)
    throws InjectionException, IOException, ParseException {
    final Configuration runtimeConfiguration =
        YarnClientConfiguration.CONF.build();
    runTaskScheduler(runtimeConfiguration, args);
  }

  /**
   * Empty private constructor to prohibit instantiation of utility class.
   */
  private SchedulerREEFYarn() {
  }
}
